@@ -44,10 +44,10 @@ build_time_vars = {'ABIFLAGS': '',
                 "-Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib -Wl,--no-as-needed -Wl,--sysroot=/' "
                 "'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.8@ABIFLAG@',
+ 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.8',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.0/coverage.info',
- 'COVERAGE_REPORT': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.0/lcov-report',
+ 'COVERAGE_INFO': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.1/coverage.info',
+ 'COVERAGE_REPORT': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.1/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include '
@@ -615,7 +615,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.0',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.1',
  'SCRIPTDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -657,10 +657,10 @@ build_time_vars = {'ABIFLAGS': '',
                '-ltcl8.6 -ltk8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.0 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.1 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.0 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.1 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -684,8 +684,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.0',
- 'abs_srcdir': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.0',
+ 'abs_builddir': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.1',
+ 'abs_srcdir': '/opt/anaconda1anaconda2anaconda3/../work/Python-3.8.1',
  'datarootdir': '/opt/anaconda1anaconda2anaconda3/share',
  'exec_prefix': '/opt/anaconda1anaconda2anaconda3',
  'prefix': '/opt/anaconda1anaconda2anaconda3',
